@@ -18,18 +18,19 @@
 #'
 #' `r lifecycle::badge("experimental")`
 #'
-#' @param x attrition table
-#' @param cohortId target cohort_definition_id
+#' @param result A summarised_result object. Output of
+#' summariseCohortAttrition().
+#' @param cohortId deprecated.
 #'
-#' @return A dgr_graph
+#' @return A `grViz` visualisation.
 #'
 #' @export
 #'
 #' @examples
 #' \donttest{
+#' library(CohortCharacteristics)
 #' library(omopgenerics)
-#' library(dplyr)
-#' library(DiagrammeR)
+#' library(dplyr, warn.conflicts = FALSE)
 #'
 #' cdm <- mockCohortCharacteristics(numberIndividuals = 1000)
 #'
@@ -40,41 +41,48 @@
 #'   recordCohortAttrition("Restrict to cohort_end_date < 2020") |>
 #'   compute(temporary = FALSE, name = "cohort1")
 #'
-#' cdm$cohort1 |>
-#'   summariseCohortAttrition() |>
+#' result <- summariseCohortAttrition(cdm$cohort1)
+#'
+#' result |>
+#'   filter(group_level == "cohort_2") |>
 #'   plotCohortAttrition(cohortId = 2)
+#'
+#' mockDisconnect(cdm)
 #' }
 #'
-plotCohortAttrition <- function(x, cohortId = NULL) {
-
+plotCohortAttrition <- function(result,
+                                cohortId = lifecycle::deprecated()) {
+  if (lifecycle::is_present(cohortId)) {
+    lifecycle::deprecate_soft("0.3.0", "plotCohortAttrition(cohortId = )")
+  }
   rlang::check_installed("DiagrammeR")
 
-  if (!inherits(x, "summarised_result")) {
-    cli::cli_abort("x must be the output of summariseCohortAttrition()")
+  if (inherits(result, "cohort_table")) {
+    result <- summariseCohortAttrition(result)
   }
-  if (nrow(x) == 0) {
-    cli::cli_warn("Empty result object")
-    return(emptyTable("Empty result object"))
+  colsAttr <- omopgenerics::cohortColumns("cohort_attrition")
+  if (inherits(result, "data.frame") && all(colsAttr %in% colnames(result))) {
+    result <- result |>
+      dplyr::select(dplyr::all_of(colsAttr)) |>
+      summariseAttrition()
   }
-  x <- x |>
-    visOmopResults::filterSettings(.data$result_type == "cohort_attrition")
-  if (nrow(x) == 0) {
+  result <- omopgenerics::validateResultArgument(result)
+  result <- result |>
+    visOmopResults::filterSettings(
+      .data$result_type == "summarise_cohort_attrition"
+    )
+  if (nrow(result) == 0) {
     cli::cli_warn("No attrition found in the results")
     return(emptyTable("No attrition found in the results"))
   }
-  if (!is.null(cohortId)) {
-    x <- x |>
-      visOmopResults::filterSettings(
-        .data$cohort_definition_id == .env$cohortId
-      )
-  }
-  if (x$result_id |> unique() |> length() > 1) {
+  nCohorts <- length(unique(result$group_level))
+  if (nCohorts > 1) {
     return(
-      emptyTable("More than one cohort found, please select only one cohort to show attrition.")
+      emptyTable(paste0(nCohorts, " present in the reuslt object, please subset to just one of them"))
     )
   }
 
-  x <- x |>
+  x <- result |>
     visOmopResults::splitAll() |>
     visOmopResults::pivotEstimates(
       pivotEstimatesBy = c("variable_name", "estimate_name"),
@@ -233,13 +241,15 @@ validateReason <- function(att) {
 
   for (k in seq_len(nrow(att))) {
     cut <- seq_len(n_char_count[k])
-    empty_positions <- stringr::str_locate_all(att$reason[k]," ") |> unlist() |> unique()
+    empty_positions <- stringr::str_locate_all(att$reason[k], " ") |>
+      unlist() |>
+      unique()
 
-    if(n_char_count[k] != 0){
-      p <- stats::quantile(empty_positions, probs = seq_len(n_char_count[k])/(n_char_count[k]+1))
+    if (n_char_count[k] != 0) {
+      p <- stats::quantile(empty_positions, probs = seq_len(n_char_count[k]) / (n_char_count[k] + 1))
       matrix_positions <- matrix(empty_positions, length(cut), length(empty_positions), byrow = TRUE)
       positions <- unique(matrix_positions[seq_len(length(cut)), apply(abs(matrix_positions - p), 1, which.min)])
-      for(kk in positions){
+      for (kk in positions) {
         substr(att$reason[k], start = kk, stop = kk) <- "\n"
       }
     }
