@@ -22,11 +22,31 @@ omopgenerics::suppress
 #' @export
 omopgenerics::settings
 
+#' @importFrom omopgenerics bind
+#' @export
+omopgenerics::bind
+
+#' @importFrom omopgenerics importSummarisedResult
+#' @export
+omopgenerics::importSummarisedResult
+
+#' @importFrom omopgenerics exportSummarisedResult
+#' @export
+omopgenerics::exportSummarisedResult
+
+#' @importFrom visOmopResults tidyColumns
+#' @export
+visOmopResults::tidyColumns
+
+#' @importFrom visOmopResults tidy
+#' @export
+visOmopResults::tidy
+
 #' It creates a mock database for testing CohortCharacteristics package
 #'
 #' @param con A DBI connection to create the cdm mock object.
 #' @param writeSchema Name of an schema on the same connection with writing
-#' permisions.
+#' permissions.
 #' @param numberIndividuals Number of individuals to create in the cdm
 #' reference.
 #' @param ... User self defined tables to put in cdm, it can input as many
