@@ -2,24 +2,24 @@
 test_that("Function returns a ggplot object", {
   skip_on_cran()
   person <- dplyr::tibble(
-    person_id = c(1, 2),
-    gender_concept_id = c(8507, 8532),
-    year_of_birth = c(1990, 1992),
-    month_of_birth = c(1, 1),
-    day_of_birth = c(1, 1),
-    race_concept_id = 0,
-    ethnicity_concept_id = 0
+    person_id = c(1, 2) |> as.integer(),
+    gender_concept_id = c(8507, 8532) |> as.integer(),
+    year_of_birth = c(1990, 1992) |> as.integer(),
+    month_of_birth = c(1, 1) |> as.integer(),
+    day_of_birth = c(1, 1) |> as.integer(),
+    race_concept_id = 0L,
+    ethnicity_concept_id = 0L
   )
   observation_period <- dplyr::tibble(
-    observation_period_id = c(1, 2),
-    person_id = c(1, 2),
+    observation_period_id = c(1, 2) |> as.integer(),
+    person_id = c(1, 2) |> as.integer(),
     observation_period_start_date = as.Date(c("2011-10-07", "2000-01-01")),
     observation_period_end_date = as.Date(c("2031-10-07", "2030-01-01")),
-    period_type_concept_id = 44814724
+    period_type_concept_id = 44814724L
   )
   cohort_interest <- dplyr::tibble(
-    cohort_definition_id = c(1, 1, 1, 2),
-    subject_id = c(1, 1, 2, 2),
+    cohort_definition_id = c(1, 1, 1, 2) |> as.integer(),
+    subject_id = c(1, 1, 2, 2) |> as.integer(),
     cohort_start_date = as.Date(c(
       "2012-10-10", "2015-01-01", "2013-10-10", "2015-01-01"
     )),
@@ -28,11 +28,11 @@ test_that("Function returns a ggplot object", {
     ))
   )
   drug_exposure <- dplyr::tibble(
-    drug_exposure_id = 1:11,
-    person_id = c(rep(1, 8), rep(2, 3)),
+    drug_exposure_id = 1:11L,
+    person_id = c(rep(1, 8), rep(2, 3)) |> as.integer(),
     drug_concept_id = c(
       rep(1125315, 2), rep(1503328, 5), 1516978, 1125315, 1503328, 1516978
-    ),
+    ) |> as.integer(),
     drug_exposure_start_date = as.Date(c(
       "2010-10-01", "2012-12-31", "2010-01-01", "2012-09-01", "2013-04-01",
       "2014-10-31", "2015-05-01", "2015-10-01", "2012-01-01", "2012-10-01",
@@ -43,15 +43,15 @@ test_that("Function returns a ggplot object", {
       "2014-12-31", "2015-05-02", "2016-10-01", "2012-01-01", "2012-10-30",
       "2015-01-10"
     )),
-    drug_type_concept_id = 38000177,
-    quantity = 1
+    drug_type_concept_id = 38000177L,
+    quantity = 1L
   )
   condition_occurrence <- dplyr::tibble(
-    condition_occurrence_id = 1:8,
-    person_id = c(rep(1, 4), rep(2, 4)),
+    condition_occurrence_id = 1:8L,
+    person_id = c(rep(1, 4), rep(2, 4)) |> as.integer(),
     condition_concept_id = c(
       317009, 378253, 378253, 4266367, 317009, 317009, 378253, 4266367
-    ),
+    ) |> as.integer(),
     condition_start_date = as.Date(c(
       "2012-10-01", "2012-01-01", "2014-01-01", "2010-01-01", "2015-02-01",
       "2012-01-01", "2013-10-01", "2014-10-10"
@@ -60,7 +60,7 @@ test_that("Function returns a ggplot object", {
       "2013-01-01", "2012-04-01", "2014-10-12", "2015-01-01", "2015-03-01",
       "2012-04-01", "2013-12-01", NA
     )),
-    condition_type_concept_id = 32020
+    condition_type_concept_id = 32020L
   )
   cdm <- mockCohortCharacteristics(
     person = person, observation_period = observation_period,
@@ -69,7 +69,7 @@ test_that("Function returns a ggplot object", {
   )
 
   concept <- dplyr::tibble(
-    concept_id = c(1125315, 1503328, 1516978, 317009, 378253, 4266367),
+    concept_id = c(1125315, 1503328, 1516978, 317009, 378253, 4266367) |> as.integer(),
     domain_id = NA_character_,
     vocabulary_id = NA_character_,
     concept_class_id = NA_character_,
@@ -91,49 +91,55 @@ test_that("Function returns a ggplot object", {
       minimumFrequency = 0
     )
 
-  # levels_ordered <- c("-inf to -366", "-365 to -31", "-30 to -1", "0 to 0", "1 to 30", "31 to 365", "366 to inf")
-  #
-  # plot <- plotLargeScaleCharacteristics(
-  #   data =  test_data |> dplyr::filter(group_level  ==  "cohort_1"),
-  #   xAxis = "variable_name",
-  #   yAxis = "estimate_value",
-  #   facetVarX = c("variable_level"),
-  #   colorVars = c("group_level", "strata_level", "strata_name"),
-  #   vertical_x = TRUE,
-  #   facetOrder = levels_ordered
-  # )
-  # expect_true(ggplot2::is.ggplot(plot))#
-
-  # levels_ordered <- c("-inf to -366.cohort_1", "-inf to -366.cohort_2",
-  #                     "-365 to -31.cohort_1", "-365 to -31.cohort_2")
   plot_multiple <- plotLargeScaleCharacteristics(
-    data = test_data |> dplyr::filter((group_level %in% c("cohort_1", "cohort_2")) | variable_name == "settings"),
-    position = "horizontal",
-    splitStrata = FALSE,
-    facet = c("variable_level", "group_level"),
-    colorVars = c("strata_level")
+    result = test_data |>
+      dplyr::filter(group_level %in% c("cohort_1", "cohort_2")),
+    facet = c("variable_level", "cohort_name"),
+    colour = c("age_group", "sex")
   )
 
   expect_true(ggplot2::is.ggplot(plot_multiple))
 
   # do not throw error even if they do not specify color or facet or position
-  expect_no_error(plotLargeScaleCharacteristics(
-    data = test_data
-  ))
-
+  expect_no_error(plotLargeScaleCharacteristics(test_data))
 
   plot_multiple <- plotComparedLargeScaleCharacteristics(
-    data = test_data |> dplyr::filter((group_level %in% c("cohort_1", "cohort_2")) | variable_name == "settings"),
-    referenceGroupLevel = "cohort_1",
-    referenceStrataLevel = "overall",
-    referenceVariableLevel = "-inf to -366",
-    referenceCdmName = NULL,
+    result = test_data |> dplyr::filter(group_level %in% c("cohort_1", "cohort_2")),
+    reference = c(cohort_name = "cohort_1", age_group = "overall", sex = "overall", variable_level = "-inf to -366"),
     facet = NULL,
-    splitStrata = FALSE,
-    colorVars = NULL,
+    colour = NULL,
     missings = 0
   )
 
   # do not throw error even if they do not specify color or facet or position
   expect_true(ggplot2::is.ggplot(plot_multiple))
 })
+
+test_that("output is always the same", {
+  set.seed(123456)
+  cdm <- omock::mockCdmReference() |>
+    omock::mockPerson(nPerson = 100) |>
+    omock::mockObservationPeriod() |>
+    omock::mockConditionOccurrence(recordPerson = 3) |>
+    omock::mockCohort(
+      numberCohorts = 3, cohortName = c("covid", "tb", "asthma")
+    )
+
+  cdm1 <- CDMConnector::copyCdmTo(
+    con = duckdb::dbConnect(duckdb::duckdb()), cdm = cdm, schema = "main"
+  )
+
+  cdm2 <- CDMConnector::copyCdmTo(
+    con = duckdb::dbConnect(duckdb::duckdb()), cdm = cdm, schema = "main"
+  )
+
+  result1 <- cdm1$cohort |>
+    summariseLargeScaleCharacteristics(eventInWindow = "condition_occurrence")
+
+  result2 <- cdm2$cohort |>
+    summariseLargeScaleCharacteristics(eventInWindow = "condition_occurrence")
+
+  expect_identical(result1, result2)
+
+  PatientProfiles::mockDisconnect(cdm = cdm)
+})
